<?php
/**
 * Retrieves and creates the wp-config.php file.
 *
 * The permissions for the base directory must allow for writing files in order
 * for the wp-config.php to be created using this page.
 *
 * @package WordPress
 * @subpackage Administration
 */

/**
 * We are installing.
 *
 * @package WordPress
 */
define('WP_INSTALLING', true);

/**
 * Disable error reporting
 *
 * Set this to error_reporting( E_ALL ) or error_reporting( E_ALL | E_STRICT ) f
or debugging
 */
error_reporting(0);

/**#@+
 * These three defines are required to allow us to use require_wp_db() to load
 * the database class while being wp-content/db.php aware.
 * @ignore
 */
define('ABSPATH', dirname(dirname(__FILE__)).'/');
define('WPINC', 'wp-includes');
define('WP_CONTENT_DIR', ABSPATH . 'wp-content');
/**#@-*/

require_once(ABSPATH . WPINC . '/compat.php');
require_once(ABSPATH . WPINC . '/functions.php');
require_once(ABSPATH . WPINC . '/classes.php');

if (!file_exists(ABSPATH . 'wp-config-sample.php'))
	wp_die('Hapunten, simkuring meryogikeun berkas wp-config-sample.php kanggo midamelna. Sumangga muat ulang éta berkas tina instalasi WordPress anjeun.');

$configFile = file(ABSPATH . 'wp-config-sample.php');

// Check if wp-config.php has been created
if (file_exists(ABSPATH . 'wp-config.php'))
	wp_die("<p>Berkas 'wp-config.php' parantos nyampak. Upami anjeun peryogi nyetél ulang item-item konfigurasina dina éta berkas, sumangga pupus heula. Anjeun tiasa nyobian <a href='install.php'>nginstalkeun ayeuna</a>.</p>");

// Check if wp-config.php exists above the root directory but is not part of another install
if (file_exists(ABSPATH . '../wp-config.php') && ! file_exists(ABSPATH . '../wp-settings.php'))
	wp_die("<p>Berkas 'wp-config.php' parantos nyampak satingkat saluhureun instalasi WordPress anjeun. Upami anjeun peryogi nyetél ulang item-item konfogurasi dina éta berkas, sumangga pupus heula. Anjeun tiasa nyobian <a href='install.php'>nginstalkeun ayeuna</a>.</p>");

if ( version_compare( '4.3', phpversion(), '>' ) )
	wp_die( sprintf( /*WP_I18N_OLD_PHP*/'Juruladén anjeun nganggo PHP vérsi %s sedeng WordPress meryogikeun paling handap vérsi 4.3.'/*/WP_I18N_OLD_PHP*/, phpversion() ) );

if ( !extension_loaded('mysql') && !file_exists(ABSPATH . 'wp-content/db.php') )
	wp_die( /*WP_I18N_OLD_MYSQL*/'Instolasi PHP anjeun kawasna kaleungitan éksténsi MySQL nu diperlukeun ku WordPress.'/*/WP_I18N_OLD_MYSQL*/ );

if (isset($_GET['step']))
	$step = $_GET['step'];
else
	$step = 0;

/**
 * Display setup wp-config.php file header.
 *
 * @ignore
 * @since 2.3.0
 * @package WordPress
 * @subpackage Installer_WP_Config
 */
function display_header() {
	header( 'Content-Type: text/html; charset=utf-8' );
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>WordPress &rsaquo; Netél Berkas Konfigurasi</title>
<link rel="stylesheet" href="css/install.css" type="text/css" />

</head>
<body>
<h1 id="logo"><img alt="WordPress" src="images/wordpress-logo.png" /></h1>
<?php
}//end function display_header();

switch($step) {
	case 0:
		display_header();
?>

<p>Wilujeng sumping ka WordPress. Sateuacana, simkuring meryogikeun sawatara informasi dina databés. Salira peryogi nguningaan sawatara hal di handap ieu sateuacan urang ngalajengkeun.</p>
<ol>
	<li>Ngaran databés</li>
	<li>Sandiasma (username) databés</li>
	<li>Sandikecap (password) databés</li>
	<li>Sandihosta (hostname) databés</li>
	<li>Préfiksu tabél (upami Salira palay ngajalankeun WordPress langkung ti hiji dina hiji databés) </li>
</ol>
<p><strong>Upami lantaran sawatara alesan wiréh nyiptakeun ieu berkas sacara otomatis téh tinemu kagagalan, teu kedah salempang. Nu dilakukeun dina ieu prosés mung ngeusikeun informasi dina databés kana berkas ropéaan. Salira ogé tiasa langsung muka <code>wp-config-sample.php</code> dina pangropéa téksu, eusikeun informasi Salira, lajeng simpen janten <code>wp-config.php</code>.</strong></p>
<p>Ilaharna, éta item-item téh dipaparinkeun ka Salira ku ISP Salira. Upami Salira henteu kagungan éta informasi, Salira peryogi ngahubungan éta ISP sateuacan Salira tiasa neraskeun. Upami Salira parantos sayogi&hellip;</p>

<p class="step"><a href="setup-config.php?step=1" class="button">Yu Urang Mimitian!</a></p>
<?php
	break;

	case 1:
		display_header();
	?>
<form method="post" action="setup-config.php?step=2">
	<p>Di handap ieu Salira kedah ngalebetkeun rincian sambungan databés Salira. Upami Salira henteu uninga éta rincian, sumangga tepangan hosta Salira. </p>
	<table class="form-table">
		<tr>
			<th scope="row"><label for="dbname">Ngaran databés</label></th>
			<td><input name="dbname" id="dbname" type="text" size="25" value="wordpress" /></td>
			<td>Ngaran databés tempat Salira badé ngajalankeun WordPress. </td>
		</tr>
		<tr>
			<th scope="row"><label for="uname">Sandiasma</label></th>
			<td><input name="uname" id="uname" type="text" size="25" value="username" /></td>
			<td>Username MySQL Salira</td>
		</tr>
		<tr>
			<th scope="row"><label for="pwd">Sandikecap</label></th>
			<td><input name="pwd" id="pwd" type="text" size="25" value="password" /></td>
			<td>...kalih password MySQL.</td>
		</tr>
		<tr>
			<th scope="row"><label for="dbhost">Sandihosta</label></th>
			<td><input name="dbhost" id="dbhost" type="text" size="25" value="localhost" /></td>
			<td>99% kasempetan geusan henteu peryogi ngarobih ieu niléy.</td>
		</tr>
		<tr>
			<th scope="row"><label for="prefix">Prefiksu Tabél</label></th>
			<td><input name="prefix" id="prefix" type="text" id="prefix" value="wp_" size="25" /></td>
			<td>Upami Salira badé ngajalankeun sababaraha WordPress dina hiji databés, robih nu ieu.</td>
		</tr>
	</table>
	<p class="step"><input name="submit" type="submit" value="Kintunkeun" class="button" /></p>
</form>
<?php
	break;

	case 2:
	$dbname  = trim($_POST['dbname']);
	$uname   = trim($_POST['uname']);
	$passwrd = trim($_POST['pwd']);
	$dbhost  = trim($_POST['dbhost']);
	$prefix  = trim($_POST['prefix']);
	if (empty($prefix)) $prefix = 'wp_';

	// Test the db connection.
	/**#@+
	 * @ignore
	 */
	define('DB_NAME', $dbname);
	define('DB_USER', $uname);
	define('DB_PASSWORD', $passwrd);
	define('DB_HOST', $dbhost);
	/**#@-*/

	// We'll fail here if the values are no good.
	require_wp_db();
	if ( !empty($wpdb->error) )
		wp_die($wpdb->error->get_error_message());

	foreach ($configFile as $line_num => $line) {
		switch (substr($line,0,16)) {
			case "define('DB_NAME'":
				$configFile[$line_num] = str_replace("putyourdbnamehere", $dbname, $line);
				break;
			case "define('DB_USER'":
				$configFile[$line_num] = str_replace("'usernamehere'", "'$uname'", $line);
				break;
			case "define('DB_PASSW":
				$configFile[$line_num] = str_replace("'yourpasswordhere'", "'$passwrd'", $line);
				break;
			case "define('DB_HOST'":
				$configFile[$line_num] = str_replace("localhost", $dbhost, $line);
				break;
			case '$table_prefix  =':
				$configFile[$line_num] = str_replace('wp_', $prefix, $line);
				break;
		}
	}
	if ( ! is_writable(ABSPATH) ) :
		display_header();
?>
<p>Sorry, but I can't write the <code>wp-config.php</code> file.</p>
<p>You can create the <code>wp-config.php</code> manually and paste the following text into it.</p>
<textarea cols="90" rows="15"><?php
		foreach( $configFile as $line ) {
			echo htmlentities($line);
		}
?></textarea>
<p>After you've done that, click "Run the install."</p>
<p class="step"><a href="install.php" class="button">Run the install</a></p>
<?php
	else :
		$handle = fopen(ABSPATH . 'wp-config.php', 'w');
		foreach( $configFile as $line ) {
			fwrite($handle, $line);
		}
		fclose($handle);
		chmod(ABSPATH . 'wp-config.php', 0666);
		display_header();
?>
<p>Saé lah! Salira parantos ngalangkungan ieu tahapan instalasi. Kiwari WordPress parantos tiasa tepung saur sareng databés Salira. Upami Salira parantos sayogi, kiwari waktosna kanggo&hellip;</p>

<p class="step"><a href="install.php" class="button">Jalankeun Instalon</a></p>
<?php
	endif;
	break;
}
?>
</body>
</html>
